use crate::error_template::*;
use leptos::*;
use leptos_meta::*;
use leptos_router::*;

use crate::web_pages::welcome_page::WelcomePage;
use crate::web_pages::chat_page::Chat;


#[component]
pub fn App() -> impl IntoView {
    // Provides context that manages stylesheets, titles, meta tags, etc.
    provide_meta_context();

    view! {


        // injects a stylesheet into the document <head>
        // id=leptos means cargo-leptos will hot-reload this stylesheet
        <Stylesheet id="leptos" href="/pkg/lavina-web-client-output.css"/>
        <Link rel="icon" type_="image/jpg" href="/lavina_logo.jpg" />
        // sets the document title
        <Title text="Lavina"/>

        // content for this welcome page
        <Router fallback=|| {
            let mut outside_errors = Errors::default();
            outside_errors.insert_with_default_key(AppError::NotFound);
            view! {
                <ErrorTemplate outside_errors/>
            }
            .into_view()
        }>
            <main>
                <Routes>
                    // <Route path="" view=WelcomePage/>
                    // <Route path="chat" view=Chat/>
                    //
                    // <Route path="test" view=Test/>
                    //
                    //
                    // // Leptos Examples
                    // <Route path="click" view=ClickExample/>
                    <Route path="progress-bar" view=ProgressBar/>

                    // <Route path="control-input" view=ControlInput/>

                </Routes>
            </main>
        </Router>
    }
}


// ### EXAMPLES ###
#[component]
fn ClickExample() -> impl IntoView {
    // Creates a reactive value to update the button
    let (count, set_count) = create_signal(0);
    let on_click = move |_| set_count.update(|count| *count += 1);

    view! {
        <h1>"Welcome to Leptos!"</h1>
        <button on:click=on_click>"Click Me: " {count}</button>
    }
}

#[component]
fn ProgressBar() -> impl IntoView {
    let (count, set_count) = create_signal(0);
    view! {
        <Link rel="icon" type_="image/jpg" href="/lavina_logo.jpg" />

        <button on:click=move |_| {
            set_count.update(|n| *n += 1);
        }>
            "Click me"
        </button>
        // now we use our component!
        <ProgressBarUnit progress=count/>
    }
}

#[component]
fn ProgressBarUnit(
    progress: ReadSignal<i32>
) -> impl IntoView {
    view! {
        <progress max="10" value=progress/>
    }
}

#[component]
fn ControlInput() -> impl IntoView {
    let (name, set_name) = create_signal("Controlled".to_string());

    view! {
    <input type="text"
        on:input=move |ev| {
            // event_target_value is a Leptos helper function
            // it functions the same way as event.target.value
            // in JavaScript, but smooths out some of the typecasting
            // necessary to make this work in Rust
            set_name(event_target_value(&ev));
        }

        // the `prop:` syntax lets you update a DOM property,
        // rather than an attribute.
        prop:value=name
    />
    <p>"Name is: " {name}</p>
}
}

#[component]
pub fn Test() -> impl IntoView {

}